@@ -14,32 +14,14 @@
 // You should have received a copy of the GNU General Public License
 // along with the snarkVM library. If not, see <https://www.gnu.org/licenses/>.
 
-pub mod amount;
-pub use amount::*;
-
 pub mod block;
 pub use block::*;
 
-pub mod block_header;
-pub use block_header::*;
+pub mod header;
+pub use header::*;
 
-pub mod block_header_hash;
-pub use block_header_hash::*;
-
-pub mod merkle_root_hash;
-pub use merkle_root_hash::*;
-
-pub mod merkle_tree;
-pub use merkle_tree::*;
-
-pub mod network;
-pub use network::*;
-
-pub mod pedersen_merkle_tree;
-pub use pedersen_merkle_tree::*;
-
-pub mod posw;
-pub use posw::ProofOfSuccinctWork;
+pub mod template;
+pub use template::*;
 
 pub mod transactions;
 pub use transactions::*;
